@@ -29,11 +29,7 @@
 
 #include <QDialog>
 
-#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
 #include <QtWidgets>
-#else
-#include <QtGui>
-#endif
 
 #include <QList>
 
