@@ -74,11 +74,14 @@ HelpAboutForm::HelpAboutForm(QWidget* parent): QDialog(parent)
 	QString about=QString("");
 	about+=tr("FET is free software for automatically scheduling the timetable of a school, high-school or university.");
 	about+=QString("<br /><br />");
+	//This is one of the two places in which we print the program's copyright period and authors.
+	//The other place is in the file src/interface/fet.cpp.
+	//(Also, don't forget about the README file and about the two files in the "man" directory!)
 	about+=tr("Copyright (C) %1 %2.", "%1 is the copyright period (a range between two years, more years separated by commas, "
-	 "or a combination of these), %2 are the copyright holders").arg("2002-2025").arg("Liviu Lalescu, Volker Dirr");
+	 "or a combination of these), %2 are the copyright holders").arg("2002-2026").arg("Liviu Lalescu, Volker Dirr");
 	about+=QString("<br /><br />");
 	about+=tr("Version: %1 (%2 %3).", "%1 is the current FET version, %2 is the current release month, %3 is the current release year").arg(FET_VERSION)
-	 .arg(QCoreApplication::translate("MonthsNames", "December")).arg("2025");
+	 .arg(QCoreApplication::translate("MonthsNames", "January")).arg("2026");
 	about+=QString("<br /><br />");
 	about+=tr("Licensed under the GNU Affero General Public License version 3.");
 	about+=QString("<br /><br />");
